==> flow-html-components-24.10-20260227.102649-39-sources.jar: com/vaadin/flow/component/html/NativeTableHeaderCell.java <==
/*
 * Copyright 2000-2026 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.vaadin.flow.component.html;

import com.vaadin.flow.component.ClickNotifier;
import com.vaadin.flow.component.Component;
import com.vaadin.flow.component.HtmlContainer;
import com.vaadin.flow.component.Tag;

/**
 * Component representing a <code>&lt;th&gt;</code> element.
 *
 * @since 24.4
 */
@Tag(Tag.TH)
public class NativeTableHeaderCell extends HtmlContainer
        implements ClickNotifier<NativeTableHeaderCell> {

    /**
     * Creates a new empty header cell component.
     */
    public NativeTableHeaderCell() {
        super();
    }

    /**
     * Creates a new header cell with the given children components.
     *
     * @param components
     *            the children components.
     */
    public NativeTableHeaderCell(Component... components) {
        super(components);
    }

    /**
     * Creates a new header cell with the given text.
     *
     * @param text
     *            the text.
     */
    public NativeTableHeaderCell(String text) {
        super();
        setText(text);
    }
}

==> flow-html-components-25.1-20260115.143019-99-sources.jar: com/vaadin/flow/component/html/NativeTableHeaderCell.java <==
/*
 * Copyright 2000-2026 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.vaadin.flow.component.html;

import java.util.Objects;

import com.vaadin.flow.component.ClickNotifier;
import com.vaadin.flow.component.Component;
import com.vaadin.flow.component.HtmlContainer;
import com.vaadin.flow.component.Tag;
import com.vaadin.signals.Signal;

/**
 * Component representing a <code>&lt;th&gt;</code> element.
 *
 * @since 24.4
 */
@Tag(Tag.TH)
public class NativeTableHeaderCell extends HtmlContainer
        implements ClickNotifier<NativeTableHeaderCell> {

    /**
     * Creates a new empty header cell component.
     */
    public NativeTableHeaderCell() {
        super();
    }

    /**
     * Creates a new header cell with the given children components.
     *
     * @param components
     *            the children components.
     */
    public NativeTableHeaderCell(Component... components) {
        super(components);
    }

    /**
     * Creates a new header cell with the given text.
     *
     * @param text
     *            the text.
     */
    public NativeTableHeaderCell(String text) {
        super();
        setText(text);
    }

    /**
     * Creates a new header cell with its text content bound to the given
     * signal.
     *
     * @param textSignal
     *            the signal to bind, not {@code null}
     * @see #bindText(Signal)
     */
    public NativeTableHeaderCell(Signal<String> textSignal) {
        Objects.requireNonNull(textSignal, "textSignal must not be null");
        bindText(textSignal);
    }
}
